==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectSubexpression.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectsubexpression_h
#define objectsubexpression_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_subexpression {
  t_math _math;
  p_expression _expression;
  int _expression_isdefault : 1;
};
#include <admsObject/objectExpression.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_subexpression_getuid (p_subexpression mysubexpression);
win32_interface gboolean adms_subexpression_cmp (p_subexpression mysubexpression,p_subexpression refsubexpression);
win32_interface p_subexpression adms_subexpression_new_1 (p_expression myexpression);
#define adms_subexpression_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_subexpression_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_subexpression_new_impl (p_adms arguments[]);
win32_interface p_subexpression adms_subexpression_impl (void* member);
#define adms_subexpression(member) ((p_subexpression) (member))
#define adms_subexpression_new adms_subexpression_new_1
#define adms_subexpression_isdefault_expression(subexpression) (adms_subexpression(subexpression)->_expression_isdefault)
#define adms_subexpression_valueof_expression(subexpression) (adms_subexpression(subexpression)->_expression)
#define adms_subexpression_valueof_math(subexpression) ((p_math)subexpression)
#define adms_subexpression_valueof_adms(subexpression) ((p_adms)subexpression)
#define adms_subexpression_valueto_expression(a,b) ((p_subexpression)a)->_expression=(b)
win32_interface void adms_subexpression_valueto_expression_impl (p_subexpression mysubexpression,p_expression _expression);
#endif /* objectsubexpression_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectSubexpression.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectsubexpression_h
#define objectsubexpression_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_subexpression {
  t_math _math;
  p_expression _expression;
  int _expression_isdefault : 1;
};
#include <admsObject/objectExpression.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_subexpression_uid (p_subexpression mysubexpression);
win32_interface int adms_subexpression_cmp (p_subexpression mysubexpression,p_subexpression refsubexpression);
win32_interface p_subexpression adms_subexpression_new(p_expression myexpression);
win32_interface p_adms adms_subexpression_new_impl (p_adms arguments[]);
#define adms_subexpression(member) ((p_subexpression) (member))
#define adms_subexpression_isdefault_expression(subexpression) (adms_subexpression(subexpression)->_expression_isdefault)
#define adms_subexpression_valueof_expression(subexpression) (adms_subexpression(subexpression)->_expression)
#define adms_subexpression_valueof_math(subexpression) ((p_math)subexpression)
#define adms_subexpression_valueof_adms(subexpression) ((p_adms)subexpression)
win32_interface inline void adms_subexpression_valueto_expression (p_subexpression mysubexpression,p_expression _expression);
win32_interface inline void adms_subexpression_free(p_subexpression mysubexpression);
#endif /* objectsubexpression_h */
